@@ -18,7 +18,7 @@ else:
   def _u(x):
     return x
 
-__version__ = '0.3.2'
+__version__ = '0.3.3'
 
 ##########
 # Python #
@@ -53,6 +53,7 @@ else:
 ########
 bit32 = struct.calcsize('P') * 8 == 32
 bit64 = struct.calcsize('P') * 8 == 64
+sparc = platform.processor() == "sparc"
 
 ##############
 # Endianness #
@@ -84,7 +85,7 @@ if osx:
 # Windows
 windows = ('win32' in str(sys.platform).lower())
 # Other
-hpux = ('hpux' in str(sys.platform).lower())
+hpux = ('hpux' in str(sys.platform).lower()) or ('hp-ux' in str(sys.platform).lower())
 solaris = ('sunos' in str(sys.platform).lower())
 
 #################
@@ -164,6 +165,9 @@ redhat_release = None
 if redhat:
   redhat_version = _u(platform.dist()[1].split('.')[0])
   redhat_release = _u(platform.dist()[1].split('.')[-1])
+# Solaris
+if solaris:
+  solaris_version = platform.release()
 
 #######
 # Env #
@@ -179,6 +183,7 @@ in_git = '.git' in os.listdir('.')
 ############
 package_deb = ubuntu or debian
 package_rpm = centos or redhat
+package_pkg = solaris
 
 ########
 # Date #
